@@ -279,7 +279,7 @@ class PluginBase:
         command that it's going to be executed.
         """
         self._current_path = current_path
-        if command_string.startswith(("sudo","python","python3")):
+        if command_string.startswith(("sudo", "python", "python3")):
             params = " ".join(command_string.split()[2:])
         else:
             params = " ".join(command_string.split()[1:])
@@ -393,7 +393,7 @@ class PluginBase:
         if ref is None:
             ref = []
         if status == "":
-            status = "opened"
+            status = "open"
         if impact is None:
             impact = {}
         if policyviolations is None:
@@ -427,7 +427,7 @@ class PluginBase:
         if ref is None:
             ref = []
         if status == "":
-            status = "opened"
+            status = "open"
         if impact is None:
             impact = {}
         if policyviolations is None:
@@ -485,7 +485,7 @@ class PluginBase:
         if ref is None:
             ref = []
         if status == "":
-            status = "opened"
+            status = "open"
         if impact is None:
             impact = {}
         if policyviolations is None:
