@@ -55,7 +55,8 @@ class WhitesourcePlugin(PluginJsonFormat):
                                                     data=data,
                                                     resolution=vulnerability['topFix']['fixResolution'],
                                                     ref=refs,
-                                                    severity=vulnerability['severity'])
+                                                    severity=vulnerability['severity'],
+                                                    cve=[vulnerability['name']])
                     else:
                         self.createAndAddVulnToHost(host_id,
                                                     name=vulnerability['name'],
@@ -76,8 +77,10 @@ class WhitesourcePlugin(PluginJsonFormat):
                         name=vulnerability['vulnerability'],
                         desc=vulnerability['description'],
                         ref=[vulnerability['link']],
-                        severity=vulnerability['severity']
+                        severity=vulnerability['severity'],
+                        cve=[vulnerability['vulnerability']]
                     )
+
                 elif 'package' in vulnerability:
                     host_id = self.createAndAddHost(vulnerability['feed_group'])
                     service_id = self.createAndAddServiceToHost(
@@ -90,7 +93,8 @@ class WhitesourcePlugin(PluginJsonFormat):
                         service_id,
                         name=f'{vulnerability["vuln"]} {vulnerability["package_name"]}',
                         ref=[vulnerability['url']],
-                        severity=vulnerability['severity']
+                        severity=vulnerability['severity'],
+                        cve=[vulnerability['vuln']]
                     )
 
 
